@@ -1,4 +1,5 @@
 # coding: utf-8
+""" save aily data of stock day and swl_day to pdsql from  tushare pro by trade_date"""
 import pandas as pd
 import numpy as np
 import os
@@ -152,7 +153,7 @@ def rq_save_stock_list_pg():
 def rq_save_stock_day_adj_fillna_pg(start_date=startDate): #20050101
     table_name='stock_day_adj_fillna'    
     t = time.localtime(time.time())
-    if int(time.strftime('%H%M%S',t))<170000:   #晚上6点之后在更新当天数据，以免不及时
+    if int(time.strftime('%H%M%S',t))<170000:   #晚上5点之后在更新当天数据，以免不及时
         t = time.localtime(time.time()-3600*24)
         tS = time.strftime("%Y-%m-%d", t)
     else:                
@@ -239,16 +240,17 @@ def rq_save_swl_day_pg(start_date=startDate, table_name='swl_day'): #from 2015-0
             save_data_to_postgresql(table_name, df, 'append')
             t1=time.time()
             tt = round((t1-t),4)
-            time.sleep(1)
+            #time.sleep(1)
             rq_util_log_info(f'save {i} {table_name} success,take {tt}S')
         except Exception as e:
             print(e)
-
+        finally:
+            pass
+        
 
 if __name__ == '__main__':          
     rq_save_stock_list_pg()
     rq_save_swl_day_pg() 
-
-    rq_save_stock_day_adj_fillna_pg(start_date='2021-05-01')
+    rq_save_stock_day_adj_fillna_pg()
         
     
