@@ -6,16 +6,18 @@ from rrshare.rqUpdate.update_swl1_index_realtime import record_swl1_index_realti
 
 from rrshare.rqUpdate.update_stock_RS_OH_MA import record_stock_PRS, record_stock_PRS_new
 
+from rrshare.rqUpdate.update_swl_RS_OH_MA import record_swl_PRS, record_swl_PRS_new
+
 
 def main_record():
     record_stock_day()
-    #record_swl_day()
+    record_swl_day()
 
     record_stock_PRS()
     record_stock_PRS_new()
 
-    record_swl_rs_valuation()
-    record_swl1_index_realtime()
+    record_swl_PRS()
+    record_swl_PRS_new
 
 
 if __name__ == '__main__':
